import { cn } from "@/lib/utils";
import { useEffect, useState } from "react";

interface NavbarProps {
  currentPath?: string;
}

export default function Navbar({ currentPath: initialPath = "" }: NavbarProps) {
  const [currentPath, setCurrentPath] = useState(initialPath);

  useEffect(() => {
    // Get current path on client-side if not provided or for client-side navigation
    if (!initialPath) {
      setCurrentPath(window.location.pathname);
    }
  }, [initialPath]);

  return (
    <>
      <div className={cn("flex flex-row justify-between pb-8 pl-4 pr-4 pt-8")}>
        <div>
          <strong className={cn("sm:text-2xl md:text-4xl")}>
            <a href="/">
            Resist Tech Monopolies
            </a>
          </strong>
        </div>
        <strong className={cn("sm:text-1xl flex gap-4 md:text-4xl")}>
          <a
            href="/GetInvolved/"
            className={cn(
              "text-blue-500",
              currentPath.includes("GetInvolved") && "border-b-2 border-blue-500"
            )}
          >
            Get Involved
          </a>
          {/* <Separator orientation="vertical" className="w-5" /> */}
          <a
            href="/PointsOfUnity/"
            className={cn(
              "text-green-500",
              currentPath.includes("PointsOfUnity") && "border-b-2 border-green-500"
            )}
          >
            Points of Unity
          </a>
          {/* <Separator orientation="vertical" className="w-5" /> */}
          <a
            href="/WhatWereWorkingOn/"
            className={cn(
              "text-red-500",
              currentPath.includes("WhatWereWorkingOn") && "border-b-2 border-red-500"
            )}
          >
            What We're Working On
          </a>
        </strong>
      </div>

      <div className={cn("flex flex-row justify-between pb-8")}>
        {[
          1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
        ].map((key) => (
          <div key={key}>
            <a
              href="https://www.flaticon.com/free-icons/computer"
              title="computer icons"
            >
              <img
                src="/computer.png"
                alt="computer icon"
                width="30"
                height="30"
              />
            </a>

            <a
              href="https://www.flaticon.com/free-icons/peopler"
              title="people icons"
            >
              <img src="/people.png" alt="people icon" width="30" height="30" />
            </a>
          </div>
        ))}
      </div>
    </>
  );
}
